@@ -1,5 +1,5 @@
 #PYME uses date based versions (yy.m.d)
-version = '20.09.01'
+version = '20.09.18'
 
 #Git changeset id
-changeset = '966a729a42c4+'
+changeset = '8333bc3b9bcf'
